/* 
 * Copyright (C) 2000-2004 the xine project
 * 
 * This file is part of xine, a unix video player.
 * 
 * xine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * xine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 * $Id: help.h,v 1.5 2004/06/13 11:44:13 f1rmb Exp $
 *
 */

#ifndef HELP_H
#define HELP_H

void help_panel(void);
void help_end(void);
int help_is_visible(void);
int help_is_running(void);
void help_toggle_visibility(xitk_widget_t *, void *);
void help_raise_window(void);
void help_reparent(void);

#endif
